searchData={"items":[{"type":"module","title":"LivePane","doc":"Function components for PaneGroup, Pane, and PaneResizer.\nAllows users to write:\n\n     \n       \n         Pane 1 \n       \n       \n         Resizer 1 \n       \n       \n         Pane 2","ref":"LivePane.html"},{"type":"function","title":"LivePane.group/1","doc":"The group component wraps a collection of panes or nested groups and manages resize events via the \"PaneGroup\" JS hook.","ref":"LivePane.html#group/1"},{"type":"function","title":"Attributes - LivePane.group/1","doc":"* `id` (`:string`) (required) - The id of the group element.\n* `direction` (`:string`) - The direction of the panes. Defaults to `\"horizontal\"`. Must be one of `\"horizontal\"`, or `\"vertical\"`.\n* `keyboard_resize_by` (`:integer`) - The amount of space to add to the pane group when the keyboard resize event is triggered.\n* `class` (`:string`) - Extra classes to apply to the group. Defaults to `\"\"`.\n* Global attributes are accepted.","ref":"LivePane.html#group/1-attributes"},{"type":"function","title":"Slots - LivePane.group/1","doc":"* `inner_block` (required)","ref":"LivePane.html#group/1-slots"},{"type":"function","title":"LivePane.pane/1","doc":"The Pane component is used to create an individual pane within a PaneGroup.","ref":"LivePane.html#pane/1"},{"type":"function","title":"Attributes - LivePane.pane/1","doc":"* `id` (`:string`) (required) - The id of the pane element.\n* `group_id` (`:string`) (required) - ID of the group this pane belongs to.\n* `class` (`:string`) - Extra classes to apply to the pane. Defaults to `\"\"`.\n* `collapsed_size` (`:integer`) - The size of the pane when it is in a collapsed state. Defaults to `0`.\n* `collapsible` (`:boolean`) - Whether the pane can be collapsed. Defaults to `false`.\n* `default_size` (`:integer`) - The default size of the pane in percentage of the group's size. Defaults to `nil`.\n* `max_size` (`:integer`) - The maximum size of the pane in percentage of the group's size. Defaults to `100`.\n* `min_size` (`:integer`) - The minimum size of the pane in percentage of the group's size. Defaults to `0`.\n* `order` (`:integer`) - The order of the pane in the group. Useful for maintaining order when conditionally rendering panes. Defaults to `0`.\n* Global attributes are accepted.","ref":"LivePane.html#pane/1-attributes"},{"type":"function","title":"Slots - LivePane.pane/1","doc":"* `inner_block` (required)","ref":"LivePane.html#pane/1-slots"},{"type":"function","title":"LivePane.resizer/1","doc":"The Resizer component is used to create a draggable handle between two panes that allows the user to resize them.","ref":"LivePane.html#resizer/1"},{"type":"function","title":"Attributes - LivePane.resizer/1","doc":"* `id` (`:string`) (required) - The id of the resize handle.\n* `group_id` (`:string`) (required) - The ID of the pane group the handle belongs to.\n* `disabled` (`:boolean`) - Whether the resize handle is disabled. Defaults to `false`.\n* `class` (`:string`) - Extra classes to apply to the handle. Defaults to `\"\"`.\n* Global attributes are accepted.","ref":"LivePane.html#resizer/1-attributes"},{"type":"function","title":"Slots - LivePane.resizer/1","doc":"* `inner_block`","ref":"LivePane.html#resizer/1-slots"},{"type":"extras","title":"Live Pane","doc":"# Live Pane\n[![Elixir CI](https://github.com/giusdp/live_pane/actions/workflows/tests.yaml/badge.svg?branch=main)](https://github.com/giusdp/live_pane/actions/workflows/tests.yaml)\n[![Hex](https://img.shields.io/hexpm/v/live_pane)](https://hex.pm/packages/live_pane)\n\nA client-side, dependency-free, set hooks and components to easily create resizable panels in your Phoenix applications.\n\nThis project has taken a lot of inspiration and code from the work done by \n[paneforge](https://.github.com/svecosystem/paneforge) and [react-resizable-panels](https://github.com/bvaughn/react-resizable-panels).","ref":"readme.html"},{"type":"extras","title":"Installation - Live Pane","doc":"Add `live_pane` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_pane, \"~> 0.3.0\"}\n  ]\nend\n```\n\nThen open up your `app.js` and import/setup the hooks.\n\nIf you have a `package.json` file at the top of `assets`, you can add this to it:\n\n```json\n\"dependencies\": {\n  \"live_pane\": \"file:../deps/live_pane\",\n},\n```\n\nAnd then import the module:\n\n```javascript\nimport { createLivePaneHooks } from 'live_pane';\n```\n\nOr you can import the file directly:\n\n```javascript\n// this path would be relative to where your app.js happens to be.\nimport { createLivePaneHooks } from '../deps/live_pane'\n```\n\nFinally setup the hooks in your `app.js` file:\n\n```javascript\nconst { groupHook, paneHook, resizerHook } = createLivePaneHooks()\n\nlet Hooks = {}\nHooks.live_pane_group = groupHook;\nHooks.live_pane = paneHook;\nHooks.live_pane_resizer = resizerHook;\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: Hooks,\n  ...\n})\n```\n\nAlso add `'../deps/live_pane/lib/**/*.*ex'` to your list of paths Tailwind will look for class names, in your\n`tailwind.config.js`:\n\n```javascript\n// assets/tailwind.config.js\n\nmodule.exports = {\n  content: [\n    './js/**/*.js',\n    '../lib/your_app_web.ex',\n    '../lib/your_app_web/**/*.*ex',\n    '../deps/live_pane/lib/**/*.*ex', <-- add this line with the correct path\n  ]\n}\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Live Pane","doc":"Now you can use the Group, Pane and Resizer components in your LiveView templates.\n\n```html\n \n   \n    One\n   \n\n   \n      \n   \n   \n    Two\n   \n \n```\n\nJust make sure to set an `id` for the group and then use the same id in each pane and resizer for the `group_id` attribute, so they can be linked together.","ref":"readme.html#usage"},{"type":"extras","title":"ROADMAP - Live Pane","doc":"(not in order)\n\n- [x] Basic 2 pane dragging\n- [x] Support nested groups\n- [x] Vertical orientation\n- [x] Collapsible panes \n- [x] Keyboard support\n- [x] Touch support\n- [ ] Events\n- [ ] Save state\n- [ ] Documentation\n- [ ] Generate IDs in pane and resizer so we don't need to set them manually","ref":"readme.html#roadmap"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\n\n## [v0.3.0] (2025-04-27)\n\n- Keyboard support for resizing panes.\n- Turn live pane components into simple function components so they can be used in dead views as well.\n- Docs site redone.\n\n## [v0.2.0] (2025-04-24)\n\n- Touch support for resizing panes.\n- Add constraints attrs to panes (it also enables collapsing).\n\n## [v0.1.0] (2025-04-23)\n\n🚀 Initial release.\n\n- Basic functionality to resize a 2-pane layout.\n- Horizontal and vertical pane orientation.\n- Basic multiple (and nested) pane groups.","ref":"changelog.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}